@@ -22,13 +22,31 @@ import logging
 import json
 
 import skink.server as server
+from skink.catalog import attributes
+
+
+def to_js_string(target):
+    if type(target) in (str, int, float, bool):
+        return json.dumps(target)
+    elif type(target) == JSObject:
+        return JSObject._command
+    else:
+        raise TypeError("{} cannot be converted to JS".format(target))
 
 
 class JSObject(object):
 
-    def __init__(self, name, page):
+    def __init__(self, name, page, attributes=None):
+        """
+            Representat a new Javascript object.
+
+            :param name: Name of the object.
+            :param page: Reference to the RemotePage.
+            :param dir: Additional fiels in dir(self).
+        """
         self._command = name
         self._page = page
+        self._attributes = attributes if attributes else []
 
     def __getattr__(self, name):
         return JSObject(self._command + '.' + name, self._page)
@@ -53,16 +71,39 @@ class JSObject(object):
             logging.debug(('__setattr__', name, value, command))
             self._page.run(command)
 
+    def __dir__(self):
+        return super().__dir__() + self._attributes
+
     def __call__(self, *args, **kwargs):
+        """
+            Return a JSObject that represents the call of the object with
+            the given parameters.
+        """
         # Converting args to strings, or adding quotes if strings:
-        args = ['"' + arg + '"' if type(arg) == str else str(arg) for arg in args]
-        command = self._command + '(' + ', '.join(args) + ')'
+        args = [to_js_string(arg) for arg in args]
+        command = "{}({})".format(self._command, ', '.join(args))
         return JSObject(command, self._page)
 
+    def __add__(self, other):
+        """
+            Returns a JSObject that represents the result of the addition
+            of two JSObjects.
+        """
+        return JSObject(
+            "( {} + {} )".format(self._command, to_js_string(other)),
+            self._page)
+
     def _run(self):
+        """
+            Send the command to be executed by all connected clients.
+        """
         return self._page.run(self._command)
 
     def _eval(self):
+        """
+            Return the value of the element in the first connected client
+            in a blocking manner.
+        """
         return self._page.eval(self._command)
 
 
@@ -73,10 +114,14 @@ class RemotePage(object):
             remote: object used to access remote JS code.
         '''
         self.path = path
-        self.document = JSObject('document', self)
-        self.window = JSObject('window', self)
-        self.alert = JSObject('alert', self)
-        self.prompt = JSObject('prompt', self)
+        self.document = JSObject('document', self,
+                                 attributes.get('document'))
+        self.window = JSObject('window', self,
+                               attributes.get('window'))
+        self.alert = JSObject('alert', self,
+                              attributes.get('alert'))
+        self.prompt = JSObject('prompt', self,
+                               attributes.get('prompt'))
 
     def run(self, command):
         logging.info(('run', [command]))
@@ -124,4 +169,3 @@ class RemotePage(object):
         handlers = server.OPEN_HANDLERS.get(self.path, [])
         handlers.append(function)
         server.OPEN_HANDLERS[self.path] = handlers
-        return function
