@@ -40,6 +40,13 @@ print('STATIC_PATH', [STATIC_PATH])
 
 
 def launch_exception(message):
+    """
+        Launch a Python exception from an error that took place in the browser.
+
+        messsage format:
+        - name: str
+        - description: str
+    """
     error_name = message['name']
     error_descr = message['description']
     mapping = {
@@ -139,11 +146,13 @@ tornado_handlers = [
     (r'/skink/socket', RealtimeHandler),
 ]
 
+
 def start(bottle_app=None, port=8080, reloader=False):
 
     if bottle_app:
         from skink.bottle_tornadosocket import TornadoWebSocketServer
-        bottle_app.run(port=port, reloader=reloader,
+        bottle_app.run(
+            port=port, reloader=reloader,
             server=TornadoWebSocketServer, handlers=tornado_handlers)
     else:
         application = tornado.web.Application(tornado_handlers, **settings)
