@@ -56,7 +56,7 @@ setup_skink_websocket = function() {
             var command = evt.data.substr(1).split("=", 2);
             console.log("raw command = [ " + command + " ]");
             var callback_id = command[0];
-            var command = command[1];
+            command = command[1];
             console.log("callback_id = [ " + callback_id + " ]");
             console.log("processed command = [ " + command + " ]");
             try {
@@ -76,7 +76,7 @@ setup_skink_websocket = function() {
                     "callback": callback_id,
                     "name": err.name,
                     "description": err.message
-                    }))
+                    }));
             }
         }
         console.log("log" + evt.data);
@@ -87,7 +87,7 @@ setup_skink_websocket = function() {
         ws.send(JSON.stringify({
             "action": "info",
             "message": "%(username)s entered the room"
-        }))
+        }));
     };
     ws.onclose = function(evt) {
         document.getElementById("stderr").innerHTML = "Connection closed by server " + evt.reason + "\n";
@@ -100,14 +100,14 @@ setup_skink_websocket = function() {
 
     window.skink = {
         ws: ws,
-        call: function(name, args=[]) {
+        call: function(name, args) {
             this.ws.send(JSON.stringify({
                 action: "callback",
                 callback: name,
                 args: args
-            }))
+            }));
         }
     };
 };
 
-window.onload = setup_skink_websocket()
+window.onload = setup_skink_websocket();
